@@ -1,15 +1,15 @@
 """A device from the Smart Device Management API."""
 
 import logging
-# Import traits for registration
 from typing import Awaitable, Callable
 
+# Import traits for registration
 from . import camera_traits  # noqa: F401
 from . import device_traits  # noqa: F401
 from . import doorbell_traits  # noqa: F401
 from . import thermostat_traits  # noqa: F401
 from .auth import AbstractAuth
-from .event import EventMessage, EventProcessingError
+from .event import EventMessage, EventProcessingError, EventTrait
 from .traits import BuildTraits, Command
 
 _LOGGER = logging.getLogger(__name__)
@@ -22,6 +22,17 @@ PARENT = "parent"
 DISPLAYNAME = "displayName"
 
 
+def _MakeEventTraitMap(traits: dict):
+    if camera_traits.CameraEventImageTrait.NAME not in traits:
+        return {}
+    event_trait_map = {}
+    for (trait_name, trait) in traits.items():
+        if not hasattr(trait, "EVENT_NAME"):
+            continue
+        event_trait_map[trait.EVENT_NAME] = trait
+    return event_trait_map
+
+
 class Device:
     """Class that represents a device object in the Google Nest SDM API."""
 
@@ -35,6 +46,7 @@ class Device:
                 continue
             self._relations[relation[PARENT]] = relation[DISPLAYNAME]
         self._callbacks = []
+        self._event_trait_map = _MakeEventTraitMap(self._traits)
 
     @staticmethod
     def MakeDevice(raw_data: dict, auth: AbstractAuth):
@@ -80,15 +92,15 @@ class Device:
         """Return the raw data string."""
         return self._raw_data
 
-    def add_update_listener(
-        self, target: Callable[[], None]
-    ) -> Callable[[], None]:
+    def add_update_listener(self, target: Callable[[], None]) -> Callable[[], None]:
         """Register a simple event listener notified on updates.
 
         The return value is a callable that will unregister the callback.
         """
+
         async def handle_event(event_message: EventMessage):
             target()
+
         return self.add_event_callback(handle_event)
 
     def add_event_callback(
@@ -127,5 +139,35 @@ class Device:
         for (trait_name, trait) in traits.items():
             self._traits[trait_name] = trait
 
+        for (event_name, event) in events.items():
+            if event_name not in self._event_trait_map:
+                continue
+            self._event_trait_map[event_name].handle_event(event)
+
         for callback in self._callbacks:
             await callback(event_message)
+
+    def active_events(self, event_types: list) -> {}:
+        """Return any active events for the specified trait names."""
+        active_events = {}
+        for event_type in event_types:
+            trait = self._event_trait_map.get(event_type)
+            if not trait or not trait.active_event:
+                continue
+            active_events[event_type] = trait.active_event
+        return active_events
+
+    @property
+    def active_event_trait(self) -> EventTrait:
+        """Return trait with the most recently received active event."""
+        trait_to_return = None
+        for trait in self._event_trait_map.values():
+            if not trait.active_event:
+                continue
+            if trait_to_return is None:
+                trait_to_return = trait
+            else:
+                event = trait.last_event
+                if event.expires_at > trait_to_return.last_event.expires_at:
+                    trait_to_return = trait
+        return trait_to_return
